package org.ow2.petals.tools.juddiAdmin.search;

import java.util.List;

import javax.xml.registry.JAXRException;
import javax.xml.registry.infomodel.Organization;
import javax.xml.registry.infomodel.Service;

/**
 * This class allows you to search services and organizations into a UDDI registry
 * with different criteria.
 * 
 * @author EL JAI Mohammed
 *
 */

public interface SearchRegistry {
	
	/**
	 * Return all the organizations registered into the registry.
	 * @return
	 * @throws JAXRException 
	 */
	public List<Organization> findAllOrganizations() throws JAXRException ;
	
	/**
	 * Return the organization whose name is the string passed in parameter. 
	 * @param name
	 * @return
	 * @throws JAXRException 
	 */
	public Organization findOrganizationByName(String name) throws JAXRException ;
	
	/**
	 * Return all the services registered into the registry.
	 * @return
	 * @throws JAXRException 
	 */
	public List<Service> findAllServices() throws JAXRException ;
	
	/**
	 * Return the service whose name is the string passed in parameter.
	 * @param name
	 * @return
	 * @throws JAXRException 
	 */
	public Service findServiceByName(String name) throws JAXRException ;
	
	/**
	 * Return the service named 'name' and provided by 'org'. 
	 * @param name service name
	 * @param org 
	 * @return
	 * @throws JAXRException 
	 */
	public Service findServiceByCompany(String name, Organization org) throws JAXRException;
	
	

}
