/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: PiePostProcessor.java msauvage $
 * -------------------------------------------------------------------------
 */
package org.ow2.petals.tools.webadmin.cewolf.postprocessors;

import java.awt.Color;
import java.awt.Font;
import java.text.NumberFormat;
import java.util.List;
import java.util.Map;

import org.jfree.chart.JFreeChart;
import org.jfree.chart.labels.StandardPieSectionLabelGenerator;
import org.jfree.chart.plot.PiePlot;
import org.jfree.util.Rotation;

import de.laures.cewolf.ChartPostProcessor;
import de.laures.cewolf.util.ImageHelper;

public class PiePostProcessor implements ChartPostProcessor {

    private static final double EXPLODE_PERCENT = 0.05;
    private static final float ALPHA = 0.8f;
    private static final int TITLE_FONT_SIZE = 12;
    private static final int START_ANGLE = 210;

    public PiePostProcessor() {
        super();
    }

    /**
     * make postprocessing on a chart (including graphic customization)
     * 
     * @param jfchart
     *            the chart to post-process
     * @param params
     *            a list of possible parameters
     */
    @SuppressWarnings("unchecked")
    public void processChart(Object jfchart, Map params) {
        JFreeChart chart = (JFreeChart) jfchart;

        chart.getTitle().setFont(new Font("sans-serif", Font.BOLD, TITLE_FONT_SIZE));

        PiePlot plot = (PiePlot) chart.getPlot();
        // label formating with pattern "ComponentName - number (percentage
        // %)"
        plot.setLabelGenerator(new StandardPieSectionLabelGenerator(
            "{0} - {1} ({2})", NumberFormat.getNumberInstance(), NumberFormat
                .getPercentInstance()));
        // plots formating
        plot.getDataset();
        plot.setStartAngle(START_ANGLE);
        plot.setDirection(Rotation.CLOCKWISE);
        plot.setForegroundAlpha(ALPHA);
        plot.setBaseSectionOutlinePaint(Color.BLACK);
        plot.setShadowXOffset(2.0);
        plot.setShadowYOffset(2.0);
        plot.setShadowPaint(Color.GRAY);
        // exploding plots : 5% each
        List<String> datasKeys = plot.getDataset().getKeys();
        for (String key : datasKeys) {
            plot.setExplodePercent(key, EXPLODE_PERCENT);
        }
    }

}
