/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.administration;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.InetAddress;
import java.net.URL;
import java.net.UnknownHostException;
import java.util.Date;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.upload.FormFile;
import org.apache.struts.validator.DynaValidatorForm;
import org.ow2.petals.tools.webadmin.cron.CollectorManager;
import org.ow2.petals.tools.webadmin.datacollector.client.exception.DataCollectorClientException;
import org.ow2.petals.tools.webadmin.datacollector.server.CollectorServer;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorClientDoesNotExistException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerNotInitializedException;
import org.ow2.petals.tools.webadmin.ui.infra.action.AdminAction;
import org.ow2.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.ow2.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.ow2.petals.tools.webadmin.util.DataCollectorHelper;
import org.ow2.petals.tools.webadmin.util.StringHelper;

public class InstallSharedLibrary extends AdminAction {

    private static final String actionTitle = "install shared library";

    final Logger log = Logger.getLogger(InstallSharedLibrary.class);

    @Override
    public ActionForward executeAdminAuthentified(ActionMapping iActionMapping,
            ActionForm iActionForm, HttpServletRequest iServletRequest,
            HttpServletResponse iServletResponse) {

        final DynaValidatorForm form = (DynaValidatorForm) iActionForm;
        final AdminSession adminSession = AdminSession
                .getAdminSession(iServletRequest.getSession());

        /** set navigation info* */
        adminSession.setSelectedMenu(AdminSession.PETALS_ADMINISTRATION);

        final FormFile componentFile = (FormFile) form.get("sharedLibraryFile");
        final String serverName = (String) form.get("server");
        final String subdomain = (String) form.get("subdomain");
        iServletRequest.setAttribute("server", serverName);
        iServletRequest.setAttribute("subdomain", subdomain);
        try {
            if (StringHelper.isNullOrEmpty(iServletRequest.getParameter("refreshAll"))) {

                final byte[] wavdatas = componentFile.getFileData();
                final ServletContext context = iServletRequest.getSession().getServletContext();

                String reqPath = iServletRequest.getContextPath();
                reqPath = reqPath.substring(reqPath.lastIndexOf("/") + 1);
                final String realContextPath = context
                        .getRealPath(iServletRequest.getContextPath());
                final String rootPath = realContextPath.substring(0, realContextPath
                        .lastIndexOf(reqPath));
                File uploadDir = new File(rootPath + "upload/");
                if (!(uploadDir.exists())) {

                    if (!(uploadDir.mkdir())) {
                        this.fillInfoBean(adminSession, "Error: can't create upload directory",
                                InfoBean.ERROR_MESSAGE);
                        return iActionMapping.findForward("success");
                    }

                }

                final String tmpDir = String.valueOf(new Date().getTime());
                uploadDir = new File(rootPath + "upload/" + tmpDir);
                if (!(uploadDir.exists())) {
                    if (!(uploadDir.mkdir())) {
                        this.fillInfoBean(adminSession, "Error: can't create upload directory",
                                InfoBean.ERROR_MESSAGE);
                        return iActionMapping.findForward("success");
                    }
                }

                final String filePath = uploadDir.getAbsolutePath() + File.separator
                        + componentFile.getFileName();

                final FileOutputStream fos = new FileOutputStream(new File(filePath));
                fos.write(wavdatas);
                fos.close();
                componentFile.destroy();

                if (serverName != null) {
                    final CollectorServer collector = CollectorManager.getCollector();
                    // constructs http url of file uploaded
                    final String jspUrl = iServletRequest.getRequestURL().toString();
                    final int lastSeparator = jspUrl.lastIndexOf("/") + 1;
                    String httpUrl = jspUrl.substring(0, lastSeparator) + "upload/" + tmpDir + "/"
                            + componentFile.getFileName();

                    /**
                     * try to replace possible "localhost" in the URL by the IP
                     * address *
                     */
                    InetAddress in = InetAddress.getLocalHost();
                    String iPaddress = "";
                    InetAddress[] all = InetAddress.getAllByName(in.getHostName());
                    for (int i = 0; (i < all.length) && (StringHelper.isNullOrEmpty(iPaddress)); i++) {
                        InetAddress ia = all[i];
                        if (ia.isReachable(5000)) {
                            iPaddress = ia.getHostAddress();
                        }
                    }
                    if (StringHelper.isNotNullAndNotEmpty(iPaddress)) {
                        httpUrl = httpUrl.replace("localhost", iPaddress);
                    }

                    collector.getCollectorClient(serverName).getInstallService()
                            .installSharedLibrary(new URL(httpUrl));

                }

                /** deals with info messages * */
                this.fillInfoBean(adminSession, "Shared Library successfully installed",
                        InfoBean.SUCCESS_MESSAGE);
                /** refresh datas from PEtALS * */
                adminSession.setDomain(DataCollectorHelper.updateDomainInfo());
            }
        } catch (final FileNotFoundException e) {
            this.fillInfoBean(adminSession, "Error: Shared Library archive file not found",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Error : can't " + InstallSharedLibrary.actionTitle, e);
        } catch (UnknownHostException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, InstallSharedLibrary.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + InstallSharedLibrary.actionTitle, e);
        } catch (final IOException e) {
            this.fillInfoBean(adminSession, "Error : Shared Library archive file not readable",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Error : can't " + InstallSharedLibrary.actionTitle, e);
        } catch (final DataCollectorClientException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, InstallSharedLibrary.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + InstallSharedLibrary.actionTitle, e);
        } catch (final DataCollectorServerException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, InstallSharedLibrary.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + InstallSharedLibrary.actionTitle, e);
        } catch (DataCollectorClientDoesNotExistException e) {
            this.fillInfoBean(adminSession,
                    "Can't reach PEtALS client, your server list must be out of date",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Error : can't " + actionTitle, e);
        } catch (DataCollectorServerNotInitializedException e) {
            CollectorManager.resetCollector();
            this.fillInfoBean(adminSession, "Connection to PEtALS lost, please refresh",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Connection to PEtALS lost : can't " + actionTitle, e);
        }

        return iActionMapping.findForward("success");

    }
}
