/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.administration;

import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.ow2.petals.tools.webadmin.cron.CollectorManager;
import org.ow2.petals.tools.webadmin.datacollector.client.exception.DataCollectorClientException;
import org.ow2.petals.tools.webadmin.datacollector.server.CollectorServer;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorClientDoesNotExistException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerNotInitializedException;
import org.ow2.petals.tools.webadmin.ui.infra.action.AdminAction;
import org.ow2.petals.tools.webadmin.ui.infra.bean.DomainLVO;
import org.ow2.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.ow2.petals.tools.webadmin.ui.infra.bean.ServerLVO;
import org.ow2.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.ow2.petals.tools.webadmin.ui.logon.LogonUtil;
import org.ow2.petals.tools.webadmin.util.DataCollectorHelper;
import org.ow2.petals.tools.webadmin.util.StringHelper;

/**
 * @author mcarpentier - EBM Websourcing
 */
public class StartStopMonitoring extends AdminAction {

    private static final String actionTitle = "use PEtALS monitoring feature";

    final Logger log = Logger.getLogger(StartStopMonitoring.class);

    @Override
    public ActionForward executeAdminAuthentified(ActionMapping iActionMapping,
            ActionForm iActionForm, HttpServletRequest iServletRequest,
            HttpServletResponse iServletResponse) {

        final AdminSession adminSession = AdminSession
                .getAdminSession(iServletRequest.getSession());

        /** set navigation info* */
        adminSession.setSelectedMenu(AdminSession.MONITORING);

        final String serverName = iServletRequest.getParameter("serv");
        boolean monitoring = false;
        boolean showMessages = false;
        boolean doNothing = false;

        final String subdomain = iServletRequest.getParameter("subdomain");
        iServletRequest.setAttribute("subdomain", subdomain);

        try {
            if (StringHelper.isNullOrEmpty(iServletRequest.getParameter("refreshAll"))) {

                if (adminSession.getDomain() == null) {
                    adminSession.setDomain(DataCollectorHelper.updateDomainInfo());
                }
                DomainLVO nLVO = adminSession.getDomain();

                final CollectorServer collector = CollectorManager.getCollector();
                // transform parameters to boolean

                if (iServletRequest.getParameter("monitoring") != null) {
                    monitoring = new Boolean(iServletRequest.getParameter("monitoring"));
                } else {
                    // no action received -> do nothing
                    doNothing = true;
                }
                if (iServletRequest.getParameter("show") != null) {
                    showMessages = new Boolean(iServletRequest.getParameter("show"));
                }

                // action received
                if (!doNothing) {
                    if (!serverName.equalsIgnoreCase("all")) {
                        if (monitoring) {
                            collector.getCollectorClient(serverName).getMonitoringService()
                                    .activateMonitoring(showMessages);
                            collector.getCollectorClient(serverName).getMonitoringService()
                                    .startListening();
                        } else {
                            collector.getCollectorClient(serverName).getMonitoringService()
                                    .deactivateMonitoring();

                        }
                    } else {
                        /** TODO : subdomains * */
                        final List<ServerLVO> servs = nLVO.getSubdomains().values().iterator()
                                .next().getServers();
                        if (monitoring) {
                            for (final ServerLVO serv : servs) {
                                collector.getCollectorClient(serv.getName()).getMonitoringService()
                                        .activateMonitoring(showMessages);
                                collector.getCollectorClient(serv.getName()).getMonitoringService()
                                        .startListening();
                            }
                        } else {
                            for (final ServerLVO serv : servs) {
                                collector.getCollectorClient(serv.getName()).getMonitoringService()
                                        .deactivateMonitoring();
                            }
                        }

                    }
                }
                /** refresh datas from PEtALS * */
                adminSession.setDomain(DataCollectorHelper.updateDomainInfo());

            }
        } catch (final DataCollectorClientException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, StartStopMonitoring.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + StartStopMonitoring.actionTitle, e);
        } catch (final DataCollectorServerException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, StartStopMonitoring.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + StartStopMonitoring.actionTitle, e);
        } catch (DataCollectorClientDoesNotExistException e) {
            this.fillInfoBean(adminSession,
                    "Can't reach PEtALS client, your server list must be out of date",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Error : can't " + actionTitle, e);
        } catch (DataCollectorServerNotInitializedException e) {
            CollectorManager.resetCollector();
            this.fillInfoBean(adminSession, "Connection to PEtALS lost, please refresh",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Connection to PEtALS lost : can't " + actionTitle, e);
          }

        return iActionMapping.findForward("success");
    }

}
