/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.infra.action;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.Action;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.ow2.petals.tools.webadmin.cron.CollectorManager;
import org.ow2.petals.tools.webadmin.datacollector.client.exception.DataCollectorClientException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorClientDoesNotExistException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerNotInitializedException;
import org.ow2.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.ow2.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.ow2.petals.tools.webadmin.ui.infra.session.WebUser;
import org.ow2.petals.tools.webadmin.ui.logon.LogonUtil;
import org.ow2.petals.tools.webadmin.util.DataCollectorHelper;
import org.ow2.petals.tools.webadmin.util.StringHelper;

/**
 * Extends each action to this class for an automatic authentification check
 * system
 * 
 * @author mcarpentier - EBM Websourcing
 * 
 */
public abstract class AuthentifiedAction extends Action {

    @Override
    public ActionForward execute(ActionMapping iActionMapping, ActionForm iActionForm,
            HttpServletRequest iServletRequest, HttpServletResponse iServletResponse)
            throws Exception {
        // --- check that user is logged in
        AdminSession session = AdminSession.getAdminSession(iServletRequest.getSession());
        WebUser webUser = session.getUser();

        if ((webUser == null) || (!CollectorManager.isCollectorInitialized())) {
            // --- redirect to logon page
            return LogonUtil.getLogonForward(iServletRequest);
        }
        try {
            if (StringHelper.isNotNullAndNotEmpty(iServletRequest.getParameter("refreshAll"))) {
                session.setDomain(DataCollectorHelper.updateDomainInfo());
            }
        } catch (DataCollectorClientException e) {
            fillInfoBeanWithExceptionMessage(session, "execute action", e.getMessage());
        } catch (DataCollectorServerNotInitializedException e) {
            fillInfoBeanWithExceptionMessage(session, "execute action", e.getMessage());
        } catch (DataCollectorClientDoesNotExistException e) {
            fillInfoBeanWithExceptionMessage(session, "execute action", e.getMessage());
        }
        //TODO : return to a global failure page
        return executeAuthentified(iActionMapping, iActionForm, iServletRequest, iServletResponse);
    }

    public abstract ActionForward executeAuthentified(ActionMapping iActionMapping,
            ActionForm iActionForm, HttpServletRequest iServletRequest,
            HttpServletResponse iServletResponse) throws Exception;

    public void fillInfoBean(AdminSession adminSession, String message, int type) {
        InfoBean ib = adminSession.getInfoBean();
        ib.setMessage(message);
        ib.setMessageType(type);
    }

    public void fillInfoBeanWithExceptionMessage(AdminSession session, String actionTitle,
            String exceptionMessage) {
        InfoBean ib = session.getInfoBean();
        ib.setMessage("Error : can't " + actionTitle + " : "
                + StringHelper.formatExceptionMessage(exceptionMessage));
        ib.setMessageType(InfoBean.ERROR_MESSAGE);
    }

    public boolean checkMandatoryParameters(HttpServletRequest req, String[] parameters,
            String actionTitle) {
        if (parameters != null) {
            for (String param : parameters) {
                if (StringHelper.isNullOrEmpty(req.getParameter(param))) {
                    /** missing parameter : fill info bean and return false* */
                    fillInfoBean(AdminSession.getAdminSession(req.getSession()), "Error : can't "
                            + actionTitle + ", missing mandatory request parameter : " + param,
                            InfoBean.ERROR_MESSAGE);
                    return false;
                }
            }
        }
        return true;
    }
}
