/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.infra.bean;

import java.util.ArrayList;
import java.util.List;

import org.ow2.petals.tools.webadmin.util.StringHelper;

/**
 * Server Light Value Object
 * 
 * @author mcarpentier - EBM Websourcing
 *
 */
public class ServerLVO {
    private String name;
    private String version;
    private String host;
    private String state;
    private String jmxPort;
    private String jmxLogin;
    private String jmxPassword;
    private String jmxState;
    private String monitor;
    
    private String networkBindPort;
    private String dreamTCPPort;
    private String joramDomainPort;
    private String jmxRMIPort;
    private String joramTCPPort;

    
    private String showMessageContent;

    private List<ComponentLVO> components;
    
    private List<ServiceAssemblyLVO> serviceAssemblies;

    private List<String> sharedLibraries;

    public ServerLVO(String serverName) {
        this.name = serverName;
    }

    public List<ComponentLVO> getComponents() {
        return components;
    }

    public void setComponents(List<ComponentLVO> components) {
        this.components = components;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public void addComponent(ComponentLVO component) {
        if (getComponents() == null) {
            this.components = new ArrayList<ComponentLVO>();
        }
        this.components.add(component);
    }
    
    public void addServiceAssembly(ServiceAssemblyLVO sa) {
        if (getServiceAssemblies() == null) {
            this.serviceAssemblies = new ArrayList<ServiceAssemblyLVO>();
        }
        this.serviceAssemblies.add(sa);
    }
    
    public ComponentLVO getComponent(String componentName) {
    	ComponentLVO result=null;
        if ((getComponents() != null) && (StringHelper.isNotNullAndNotEmpty(componentName))){
        	for (ComponentLVO c : getComponents()) {
        		if (componentName.equalsIgnoreCase(c.getName())) {
        			result=c;
        		}
        	}
        }
       return result;
    }

    public List<ComponentLVO> getBindingComponents() {
        List<ComponentLVO> result = new ArrayList<ComponentLVO>();
        if (getComponents() != null) {
            for (ComponentLVO component : getComponents()) {
                if (ComponentLVO.BC_TYPE.equalsIgnoreCase(component.getType())) {
                    result.add(component);
                }
            }
        }
        return result;
    }

    public List<ComponentLVO> getServiceEngines() {
        List<ComponentLVO> result = new ArrayList<ComponentLVO>();

        if (getComponents() != null) {
            for (ComponentLVO component : getComponents()) {
                if (ComponentLVO.SE_TYPE.equalsIgnoreCase(component.getType())) {
                    result.add(component);
                }
            }
        }
        return result;
    }

	public String getHost() {
		return host;
	}

	public void setHost(String host) {
		this.host = host;
	}

	public String getJmxLogin() {
		return jmxLogin;
	}

	public void setJmxLogin(String jmxLogin) {
		this.jmxLogin = jmxLogin;
	}

	public String getJmxPassword() {
		return jmxPassword;
	}

	public void setJmxPassword(String jmxPassword) {
		this.jmxPassword = jmxPassword;
	}

	public String getJmxPort() {
		return jmxPort;
	}

	public void setJmxPort(String jmxPort) {
		this.jmxPort = jmxPort;
	}

	public String getJmxState() {
		return jmxState;
	}

	public void setJmxState(String jmxState) {
		this.jmxState = jmxState;
	}

	public String getMonitor() {
		return monitor;
	}

	public void setMonitor(String monitor) {
		this.monitor = monitor;
	}

	public String getShowMessageContent() {
		return showMessageContent;
	}

	public void setShowMessageContent(String showMessageContent) {
		this.showMessageContent = showMessageContent;
	}

	public String getState() {
		return state;
	}

	public void setState(String state) {
		this.state = state;
	}

    public List<ServiceAssemblyLVO> getServiceAssemblies() {
        return serviceAssemblies;
    }

    public String getNetworkBindPort() {
        return networkBindPort;
    }

    public void setNetworkBindPort(String networkBindPort) {
        this.networkBindPort = networkBindPort;
    }

    public String getDreamTCPPort() {
        return dreamTCPPort;
    }

    public void setDreamTCPPort(String dreamTCPPort) {
        this.dreamTCPPort = dreamTCPPort;
    }

    public String getJoramDomainPort() {
        return joramDomainPort;
    }

    public void setJoramDomainPort(String joramDomainPort) {
        this.joramDomainPort = joramDomainPort;
    }

    public String getJmxRMIPort() {
        return jmxRMIPort;
    }

    public void setJmxRMIPort(String jmxRMIPort) {
        this.jmxRMIPort = jmxRMIPort;
    }

    public String getJoramTCPPort() {
        return joramTCPPort;
    }

    public void setJoramTCPPort(String joramTCPPort) {
        this.joramTCPPort = joramTCPPort;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public List<String> getSharedLibraries() {
        return sharedLibraries;
    }

    public void setSharedLibraries(List<String> sharedLibraries) {
        this.sharedLibraries = sharedLibraries;
    }
    
    public void addSharedLibrary(String sharedLibraryName){
        if (this.sharedLibraries == null) {
            this.sharedLibraries = new ArrayList<String>();
        }
        this.sharedLibraries.add(sharedLibraryName);
    }


}
