/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.infra.bean;

import java.util.ArrayList;
import java.util.List;

/**
 * Server Light Value Object
 * 
 * @author mcarpentier - EBM Websourcing
 * 
 */
public class SubdomainLVO {
    private String name;

    private List<ServerLVO> servers;

    public SubdomainLVO() {
        super();
        this.servers = new ArrayList<ServerLVO>();
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public List<ServerLVO> getServers() {
        return servers;
    }

    public void setServers(List<ServerLVO> servers) {
        this.servers = servers;
    }

    public void addServer(ServerLVO server) {
        if (servers == null) {
            servers = new ArrayList<ServerLVO>();
        }
        servers.add(server);
    }

    public SubdomainLVO(String name) {
        super();
        this.name = name;
    }

    /**
     * 
     * get all endpoints of the subdomain
     * 
     * @return
     */
    public List<EndPointLVO> getAllEndpoints() {
        List<EndPointLVO> epsLVO = new ArrayList<EndPointLVO>();
        for (ServerLVO sLVO : this.getServers()) {
            if (sLVO.getComponents() != null) {
                for (ComponentLVO cLVO : sLVO.getComponents()) {
                    if (cLVO.getEndpoints() != null) {

                        for (EndPointLVO epLVO : cLVO.getEndpoints()) {
                            epsLVO.add(epLVO);
                        }
                    }
                }
            }
        }
        return epsLVO;
    }

    /**
     * Each server has an unique name
     * 
     * @param serverName
     * @return
     */
    public ServerLVO getServerLVO(String serverName) {
        for (ServerLVO sLVO : this.getServers()) {
            if (serverName.equalsIgnoreCase(sLVO.getName())) {
                return sLVO;
            }
        }
        return null;
    }

    /**
     * Each server has an unique name
     * 
     * @param serverName
     * @return
     */
    public List<String> getServersName() {
        List<String> result = new ArrayList<String>();
        for (ServerLVO sLVO : this.getServers()) {
            result.add(sLVO.getName());
        }
        return result;
    }

}
