/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.juddi;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.registry.JAXRException;
import javax.xml.registry.infomodel.Organization;
import javax.xml.registry.infomodel.Service;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.DynaActionForm;
import org.ow2.petals.tools.juddiAdmin.search.SearchRegistry;
import org.ow2.petals.tools.juddiAdmin.search.SearchRegistryImpl;
import org.ow2.petals.tools.webadmin.ui.infra.action.JuddiAction;
import org.ow2.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.ow2.petals.tools.webadmin.util.StringHelper;
import org.ow2.petals.tools.webadmin.util.WebConsoleConfigException;

/**
 * Upload a component to a temporary directory and install it
 * 
 * request params : componentFile, server
 * 
 * @author mcarpentier - EBM Websourcing
 * 
 */
public class ShowAddPetalsService extends JuddiAction {

    private static final String actionTitle = "get services";

    final Logger log = Logger.getLogger(ShowAddPetalsService.class);

    @Override
    public ActionForward executeJuddiAuthentified(ActionMapping iActionMapping, ActionForm iActionForm,
            HttpServletRequest iServletRequest, HttpServletResponse iServletResponse) {

        final DynaActionForm form = (DynaActionForm) iActionForm;
        final AdminSession adminSession = AdminSession
                .getAdminSession(iServletRequest.getSession());

        /** set navigation info* */
        adminSession.setSelectedMenu(AdminSession.JUDDI_ADMINISTRATION);

        /** get all request parameters* */
        String compo = iServletRequest.getParameter("compo");
        if (StringHelper.isNullOrEmpty(compo)) {
            compo = form.getString("component");
        }
        String server = iServletRequest.getParameter("serv");
        if (StringHelper.isNullOrEmpty(server)) {
            server = form.getString("server");
        }
        String endpoint = iServletRequest.getParameter("endpoint");
        if (StringHelper.isNullOrEmpty(endpoint)) {
            server = form.getString("endpoint");
        }
        String endpointService = iServletRequest.getParameter("endpointService");
        if (StringHelper.isNullOrEmpty(endpointService)) {
            server = form.getString("endpointService");
        }
        final String organization = form.getString("organization2");

        try {
            if ((!(StringHelper.isNullOrEmpty(compo)) && (!(StringHelper.isNullOrEmpty(server))))) {

                form.set("component", compo);
                form.set("server", server);
                form.set("endpoint", endpoint);
                form.set("endpointService", endpointService);

                // get search object
                final SearchRegistry search = new SearchRegistryImpl();
                // get all the organizations registered into UDDI registry
                final List<Organization> organizations = search.findAllOrganizations();
                form.set("organizations", organizations);

                if (!StringHelper.isNullOrEmpty(organization)) {
                    final Organization or = search.findOrganizationByName(organization);
                    // get all the services registered into UDDI registry
                    final Collection<Service> services = or.getServices();
                    final ArrayList<Service> servicesList = new ArrayList<Service>();
                    if ((services != null) && (services.size() > 0)) {
                        for (final Service s : services) {
                            servicesList.add(s);
                        }
                        form.set("services", servicesList);
                    }
                }
            }
        } catch (final JAXRException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, ShowAddPetalsService.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + ShowAddPetalsService.actionTitle, e);
        } catch (WebConsoleConfigException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, ShowAddPetalsService.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + ShowAddPetalsService.actionTitle, e);
        }

        form.set("component", compo);

        return iActionMapping.findForward("success");

    }
}
