/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.juddi;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.registry.JAXRException;
import javax.xml.registry.infomodel.Organization;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.validator.DynaValidatorForm;
import org.ow2.petals.tools.juddiAdmin.search.SearchRegistry;
import org.ow2.petals.tools.juddiAdmin.search.SearchRegistryImpl;
import org.ow2.petals.tools.juddiAdmin.update.UpdateRegistry;
import org.ow2.petals.tools.juddiAdmin.update.UpdateRegistryImpl;
import org.ow2.petals.tools.webadmin.ui.infra.action.JuddiAction;
import org.ow2.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.ow2.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.ow2.petals.tools.webadmin.util.WebConsoleConfigException;

/**
 * Upload a component to a temporary directory and install it
 * 
 * request params : componentFile, server
 * 
 * @author mcarpentier - EBM Websourcing
 * 
 */
public class SubmitBusinessService extends JuddiAction {

    private static final String actionTitle = "add a service";

    final Logger log = Logger.getLogger(SubmitBusinessService.class);

    @Override
    public ActionForward executeJuddiAuthentified(ActionMapping iActionMapping, ActionForm iActionForm,
            HttpServletRequest iServletRequest, HttpServletResponse iServletResponse) {

        final DynaValidatorForm form = (DynaValidatorForm) iActionForm;
        final AdminSession adminSession = AdminSession
                .getAdminSession(iServletRequest.getSession());

        /** get form datas * */
        final String organizationName = (String) form.get("organization");
        final String serviceName = (String) form.get("serviceName");
        final String serviceDescription = (String) form.get("serviceDescription");
        // create a UpdateRegistry Object
        try {
            final UpdateRegistry update = new UpdateRegistryImpl();
            final SearchRegistry search = new SearchRegistryImpl();
            final Organization org = search.findOrganizationByName(organizationName);
            // create organization and save it into a UDDI registry
            update.createBusinessService(serviceName, serviceDescription, org);

            /** deals with info messages * */
            this.fillInfoBean(adminSession, "Business Service successfully added",
                    InfoBean.SUCCESS_MESSAGE);

        } catch (final JAXRException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, SubmitBusinessService.actionTitle,
                    e.getMessage());
            this.log.error("Error : can't " + SubmitBusinessService.actionTitle, e);
        } catch (WebConsoleConfigException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, SubmitBusinessService.actionTitle,
                    e.getMessage());
            this.log.error("Error : can't " + SubmitBusinessService.actionTitle, e);
        }

        // reset form fields
        form.initialize(iActionMapping);

        return iActionMapping.findForward("success");

    }
}
