/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.logon;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.DynaActionForm;
import org.ow2.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.ow2.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.ow2.petals.tools.webadmin.ui.infra.session.WebUser;
import org.ow2.petals.tools.webadmin.util.ConfigHelper;
import org.ow2.petals.tools.webadmin.util.StringHelper;
import org.ow2.petals.tools.webadmin.util.WebConsoleConfigException;
import org.ow2.petals.tools.webadmin.util.WebconsoleConfiguration;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

/**
 * Triggered when an user logs in
 * 
 * @author mcarpentier
 * 
 */
public class ConsoleLogon extends Action {
    @Override
    public ActionForward execute(ActionMapping iActionMapping, ActionForm form,
            HttpServletRequest iRequest, HttpServletResponse iResponse) {

        final Logger log = Logger.getLogger(ConsoleLogon.class);

        DynaActionForm logonForm = (DynaActionForm) form;

        String consoleLogin = (String) logonForm.get("login");
        String consolePwd = (String) logonForm.get("password");
        String nextUrl = (String) logonForm.get("nextUrl");

        AdminSession adminSession = AdminSession.getAdminSession(iRequest.getSession());

        /** deals with error messages * */
        InfoBean infoBean = adminSession.getInfoBean();

        /**
         * TODO : login system with user/pwd TODO : check if datacollector is
         * reachable and ready (petals reachable, hsqldb reachable)
         * 
         */
        WebUser webUser = new WebUser();
        webUser.setLogin(consoleLogin);
        try {
            WebconsoleConfiguration conf = new WebconsoleConfiguration(ConfigHelper
                    .getConfig("webconsole-users.xml"));
            Node n = conf.getNodeFromProperty("webconsole-users", "user", "username", consoleLogin);
            boolean authenticated = false;
            if (n != null) {
                NamedNodeMap list = n.getAttributes();
                String roles = "";
                for (int a = 0; a < list.getLength(); a++) {
                    if ("roles".equalsIgnoreCase(list.item(a).getNodeName())) {
                        roles = list.item(a).getNodeValue();
                    }
                    if (("password".equalsIgnoreCase(list.item(a).getNodeName()))
                            && (list.item(a).getNodeValue()).equalsIgnoreCase(consolePwd)) {
                        authenticated = true;
                    }
                }

                /** user authentification succeed, set roles* */
                webUser.setRoles(roles);

            }
            if (!authenticated) {
                infoBean.setMessage("Error : invalid username/password");
                infoBean.setMessageType(InfoBean.ERROR_MESSAGE);
                return iActionMapping.findForward("failure");
            }

        } catch (WebConsoleConfigException e) {
            infoBean.setMessage("Error : " + StringHelper.formatExceptionMessage(e.getMessage()));
            infoBean.setMessageType(InfoBean.ERROR_MESSAGE);
            log.error("Error : login failure", e);
            return iActionMapping.findForward("failure");
        }
        /** set user logged * */
        adminSession.setUser(webUser);

        /** TODO : set Role * */

        if ((nextUrl == null) || (nextUrl.length() == 0)) {
            if (adminSession.getUser().isAdmin()) {
                return iActionMapping.findForward("admin_success");
            } else {
                return iActionMapping.findForward("monitoring_success");
            }
        }

        return new ActionForward(nextUrl, true);

    }
}
