/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.monitoring;

/**
 * @author mcarpentier - EBM Websourcing
 */
import java.util.Collections;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.DynaActionForm;
import org.ow2.petals.tools.webadmin.cron.CollectorManager;
import org.ow2.petals.tools.webadmin.datacollector.client.exception.DataCollectorClientException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorClientDoesNotExistException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerNotInitializedException;
import org.ow2.petals.tools.webadmin.ui.infra.action.MonitoringAction;
import org.ow2.petals.tools.webadmin.ui.infra.bean.DomainLVO;
import org.ow2.petals.tools.webadmin.ui.infra.bean.EndPointLVO;
import org.ow2.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.ow2.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.ow2.petals.tools.webadmin.ui.infra.util.EndpointLVOComparator;
import org.ow2.petals.tools.webadmin.ui.logon.LogonUtil;
import org.ow2.petals.tools.webadmin.util.DataCollectorHelper;

public class ShowEndpoints extends MonitoringAction {

    private static final String actionTitle = "get endpoints";

    final Logger log = Logger.getLogger(ShowEndpoints.class);

    @Override
    public ActionForward executeMonitoringAuthentified(ActionMapping iActionMapping,
            ActionForm iActionForm, HttpServletRequest iServletRequest,
            HttpServletResponse iServletResponse) {
        final AdminSession adminSession = AdminSession
                .getAdminSession(iServletRequest.getSession());

        /** set navigation info* */
        adminSession.setSelectedMenu(AdminSession.MONITORING);

        final DynaActionForm form = (DynaActionForm) iActionForm;

        final String sortType = iServletRequest.getParameter("sort");
        final String sortOrder = iServletRequest.getParameter("order");

        form.set("sortType", sortType);
        form.set("sortOrder", sortOrder);

        String subdomainName;
        if (iServletRequest.getAttribute("subdomain") != null) {
            subdomainName = (String) iServletRequest.getAttribute("subdomain");
        } else {
            subdomainName = iServletRequest.getParameter("subdomain");
        }
        iServletRequest.setAttribute("subdomain", subdomainName);

        try {
            if (adminSession.getDomain() == null) {
                adminSession.setDomain(DataCollectorHelper.updateDomainInfo());
            }
            DomainLVO nLVO = adminSession.getDomain();
            if (nLVO.getSubdomains().containsKey(subdomainName)) {

                List<EndPointLVO> epsLVO = nLVO.getSubdomains().get(subdomainName)
                        .getAllEndpoints();

                Collections.sort(epsLVO, new EndpointLVOComparator(sortType, sortOrder));
                form.set("endpoints", epsLVO);
            } else {
                this.fillInfoBean(adminSession, "Can't " + ShowEndpoints.actionTitle
                        + " : can't find subdomain " + subdomainName, InfoBean.ERROR_MESSAGE);
            }
        } catch (final DataCollectorClientException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, ShowEndpoints.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + ShowEndpoints.actionTitle, e);
        } catch (final DataCollectorServerException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, ShowEndpoints.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + ShowEndpoints.actionTitle, e);
        } catch (DataCollectorClientDoesNotExistException e) {
            this.fillInfoBean(adminSession,
                    "Can't reach PEtALS client, your server list must be out of date",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Error : can't " + actionTitle, e);
        } catch (DataCollectorServerNotInitializedException e) {
            CollectorManager.resetCollector();
            this.fillInfoBean(adminSession, "Connection to PEtALS lost, please refresh",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Connection to PEtALS lost : can't " + actionTitle, e);
            return LogonUtil.getLogonForward(iServletRequest);
        }

        return iActionMapping.findForward("success");
    }

}
