/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.monitoring;

import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.DynaActionForm;
import org.ow2.petals.tools.webadmin.cron.CollectorManager;
import org.ow2.petals.tools.webadmin.datacollector.client.exception.DataCollectorClientException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorClientDoesNotExistException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerNotInitializedException;
import org.ow2.petals.tools.webadmin.ui.infra.action.MonitoringAction;
import org.ow2.petals.tools.webadmin.ui.infra.bean.ComponentLVO;
import org.ow2.petals.tools.webadmin.ui.infra.bean.DomainLVO;
import org.ow2.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.ow2.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.ow2.petals.tools.webadmin.ui.logon.LogonUtil;
import org.ow2.petals.tools.webadmin.util.DataCollectorHelper;
import org.ow2.petals.tools.webadmin.util.StringHelper;

/**
 * @author mcarpentier - EBM Websourcing
 */
public class ShowQueuesInfo extends MonitoringAction {

    private static final String actionTitle = "get PEtALS queues details";

    final Logger log = Logger.getLogger(ShowQueuesInfo.class);

    @Override
    public ActionForward executeMonitoringAuthentified(ActionMapping iActionMapping,
            ActionForm iActionForm, HttpServletRequest iServletRequest,
            HttpServletResponse iServletResponse) {

        final AdminSession adminSession = AdminSession
                .getAdminSession(iServletRequest.getSession());

        /** set navigation info* */
        adminSession.setSelectedMenu(AdminSession.MONITORING);

        String serverName = iServletRequest.getParameter("server");
        String component = iServletRequest.getParameter("selectedComponent");

        final DynaActionForm form = (DynaActionForm) iActionForm;

        if (StringHelper.isNullOrEmpty(component)) {
            component = form.getString("selectedComponent");
        }

        if (StringHelper.isNullOrEmpty(serverName)) {
            serverName = form.getString("serverName");
        }

        String subdomainName;
        if (iServletRequest.getAttribute("subdomain") != null) {
            subdomainName = (String) iServletRequest.getAttribute("subdomain");
        } else {
            subdomainName = iServletRequest.getParameter("subdomain");
        }

        try {
            if (adminSession.getDomain() == null) {
                adminSession.setDomain(DataCollectorHelper.updateDomainInfo());
            }
            DomainLVO nLVO = adminSession.getDomain();
            if (nLVO.getSubdomains().containsKey(subdomainName)) {
                List<ComponentLVO> components = nLVO.getSubdomains().get(subdomainName)
                        .getServerLVO(serverName).getComponents();

                form.set("components", components);
                if (StringHelper.isNullOrEmpty(component)) {
                    if ((components != null) && (components.size() > 0)) {
                        form.set("selectedComponent", components.get(0).getName());
                    }
                } else {
                    form.set("selectedComponent", component);
                }
            } else {
                this.fillInfoBean(adminSession, "Can't " + ShowQueuesInfo.actionTitle
                        + " : can't find subdomain " + subdomainName, InfoBean.ERROR_MESSAGE);
            }
        } catch (final DataCollectorServerException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, ShowQueuesInfo.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + ShowQueuesInfo.actionTitle, e);
        } catch (final DataCollectorClientException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, ShowQueuesInfo.actionTitle, e
                    .getMessage());
            this.log.error("Error : can't " + ShowQueuesInfo.actionTitle, e);
        } catch (DataCollectorClientDoesNotExistException e) {
            this.fillInfoBean(adminSession,
                    "Can't reach PEtALS client, your server list must be out of date",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Error : can't " + actionTitle, e);
        } catch (DataCollectorServerNotInitializedException e) {
            CollectorManager.resetCollector();
            this.fillInfoBean(adminSession, "Connection to PEtALS lost, please refresh",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Connection to PEtALS lost : can't " + actionTitle, e);
            return LogonUtil.getLogonForward(iServletRequest);
        }
        form.set("serverName", serverName);

        return iActionMapping.findForward("success");
    }

}
