/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.tools.webadmin.ui.portlet;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.management.ObjectName;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.DynaActionForm;
import org.ow2.petals.tools.webadmin.cron.CollectorManager;
import org.ow2.petals.tools.webadmin.datacollector.client.exception.DataCollectorClientException;
import org.ow2.petals.tools.webadmin.datacollector.server.CollectorServer;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorClientDoesNotExistException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerException;
import org.ow2.petals.tools.webadmin.datacollector.server.exception.DataCollectorServerNotInitializedException;
import org.ow2.petals.tools.webadmin.ui.administration.InstallComponent;
import org.ow2.petals.tools.webadmin.ui.infra.action.AuthentifiedAction;
import org.ow2.petals.tools.webadmin.ui.infra.bean.ComponentLVO;
import org.ow2.petals.tools.webadmin.ui.infra.bean.InfoBean;
import org.ow2.petals.tools.webadmin.ui.infra.bean.QueueLVO;
import org.ow2.petals.tools.webadmin.ui.infra.session.AdminSession;
import org.ow2.petals.tools.webadmin.ui.logon.LogonUtil;

/**
 * @author mcarpentier - EBM Websourcing
 */
public class ShowQueues extends AuthentifiedAction {

    final Logger log = Logger.getLogger(ShowQueues.class);

    private static final String actionTitle = "get PEtALS components";

    @Override
    public ActionForward executeAuthentified(ActionMapping iActionMapping, ActionForm iActionForm,
            HttpServletRequest iServletRequest, HttpServletResponse iServletResponse) {

        AdminSession adminSession = AdminSession.getAdminSession(iServletRequest.getSession());

        String serverName = iServletRequest.getParameter("server");
        String componentName = iServletRequest.getParameter("component");

        /** set navigation info* */
        adminSession.setSelectedMenu(AdminSession.MONITORING);
        adminSession.setSelectedComponent(componentName);

        DynaActionForm form = (DynaActionForm) iActionForm;

        form.set("serverName", serverName);

        try {
            CollectorServer collector = CollectorManager.getCollector();
            /** TODO : use DataCollectorHelper * */
            ObjectName[] objComps = collector.getCollectorClient(serverName).getAdminService()
                    .getBindingComponents();
            for (ObjectName objectName : objComps) {
                String name = objectName.getKeyProperty("name");
                if (componentName.equalsIgnoreCase(name)) {
                    String objState = collector.getCollectorClient(serverName).getAdminService()
                            .getComponentState(name);
                    form.set("name", name);
                    form.set("type", ComponentLVO.BC_TYPE);
                    form.set("description", "");
                    form.set("objectName", objectName.getCanonicalName());
                    form.set("state", objState);

                    List<String> transporters = collector.getCollectorClient(serverName)
                            .getTransportMonitoringService().getTransporters();
                    ArrayList<QueueLVO> queues = new ArrayList<QueueLVO>();

                    for (String transporter : transporters) {
                        String nameArray[] = transporter.split("-");
                        String formattedQueue = "";
                        if (nameArray.length > 1) {
                            formattedQueue = nameArray[nameArray.length - 1] + " queue";
                        } else {
                            formattedQueue = transporter;
                        }
                        Map<String, Integer> queueValue = collector.getCollectorClient(serverName)
                                .getTransportMonitoringService().getQueueCurrentSizes(transporter);
                        for (String key : queueValue.keySet()) {
                            if (key.equalsIgnoreCase(componentName)) {
                                queues.add(new QueueLVO(formattedQueue, "unknown", String
                                        .valueOf(queueValue.get(key))));
                            }
                        }

                    }
                    form.set("queues", queues);
                }
            }

        } catch (DataCollectorServerException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, actionTitle, e.getMessage());
            this.log.error("Error : can't " + actionTitle, e);
        } catch (DataCollectorClientException e) {
            this.fillInfoBeanWithExceptionMessage(adminSession, actionTitle, e.getMessage());
            this.log.error("Error : can't " + actionTitle, e);
        } catch (DataCollectorClientDoesNotExistException e) {
            this.fillInfoBean(adminSession,
                    "Can't reach PEtALS client, your server list must be out of date",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Error : can't " + actionTitle, e);
        } catch (DataCollectorServerNotInitializedException e) {
            CollectorManager.resetCollector();
            this.fillInfoBean(adminSession, "Connection to PEtALS lost, please refresh",
                    InfoBean.ERROR_MESSAGE);
            this.log.error("Connection to PEtALS lost : can't " + actionTitle, e);
            return LogonUtil.getLogonForward(iServletRequest);
        }

        return iActionMapping.findForward("success");
    }

}
